@@ -159,6 +159,7 @@ def run_pipx_command(args: argparse.Namespace):  # noqa: C901
             verbose,
             force=args.force,
             include_dependencies=args.include_deps,
+            suffix=args.suffix,
         )
     elif args.command == "inject":
         if not args.include_apps and args.include_deps:
@@ -204,7 +205,7 @@ def run_pipx_command(args: argparse.Namespace):  # noqa: C901
         return commands.run_pip(package, venv_dir, args.pipargs, args.verbose)
     elif args.command == "ensurepath":
         try:
-            return commands.ensure_path(constants.LOCAL_BIN_DIR, force=args.force)
+            return commands.ensure_pipx_paths(force=args.force)
         except Exception as e:
             raise PipxError(e)
     elif args.command == "completions":
@@ -261,6 +262,9 @@ def _add_install(subparsers):
         action="store_true",
         help="Modify existing virtual environment and files in PIPX_BIN_DIR",
     )
+    p.add_argument(
+        "--suffix", help="Optional suffix for virtual environment and executable names"
+    )
     p.add_argument(
         "--python",
         default=constants.DEFAULT_PYTHON,
@@ -480,8 +484,10 @@ def _add_ensurepath(subparsers):
     p = subparsers.add_parser(
         "ensurepath",
         help=(
-            "Ensure directory where pipx stores apps is on your "
-            "PATH environment variable. Note that running this may modify "
+            "Ensure directory where pipx stores apps is in your "
+            "PATH environment variable. Also if pipx was installed via "
+            "`pip install --user`, ensure pipx itself is in your PATH. "
+            "Note that running this may modify "
             "your shell's configuration file(s) such as '~/.bashrc'."
         ),
     )
@@ -491,7 +497,7 @@ def _add_ensurepath(subparsers):
         action="store_true",
         help=(
             "Add text to your shell's config file even if it looks like your "
-            f"PATH already has {str(constants.LOCAL_BIN_DIR)}"
+            "PATH already contains paths to pipx and pipx-install apps."
         ),
     )
 
@@ -543,6 +549,7 @@ def setup(args):
     else:
         logging.basicConfig(level=logging.WARNING, format="%(message)s")
 
+    logging.info(f"pipx version is {__version__}")
     mkdir(constants.PIPX_LOCAL_VENVS)
     mkdir(constants.LOCAL_BIN_DIR)
     mkdir(constants.PIPX_VENV_CACHEDIR)
