@@ -1,14 +1,16 @@
 import json
 import logging
 import pkgutil
-import re
-import urllib.parse
 from pathlib import Path
-from typing import Generator, List, NamedTuple, Dict, Set, Optional
+from typing import Dict, Generator, List, NamedTuple, Set
 
 from pipx.animate import animate
 from pipx.constants import DEFAULT_PYTHON, PIPX_SHARED_PTH
-from pipx.pipx_metadata_file import PipxMetadata, PackageInfo
+from pipx.package_specifier import (
+    parse_specifier_for_install,
+    parse_specifier_for_metadata,
+)
+from pipx.pipx_metadata_file import PackageInfo, PipxMetadata
 from pipx.shared_libs import shared_libs
 from pipx.util import (
     PipxError,
@@ -18,10 +20,8 @@ from pipx.util import (
     rmdir,
     run,
     run_subprocess,
-    valid_pypi_name,
 )
 
-
 venv_metadata_inspector_raw = pkgutil.get_data("pipx", "venv_metadata_inspector.py")
 assert venv_metadata_inspector_raw is not None, (
     "pipx could not find required file venv_metadata_inspector.py. "
@@ -162,20 +162,20 @@ class Venv:
 
     def install_package(
         self,
-        package: Optional[str],  # if None, will be determined in this function
+        package: str,
         package_or_url: str,
         pip_args: List[str],
         include_dependencies: bool,
         include_apps: bool,
         is_main_package: bool,
     ) -> None:
-
         if pip_args is None:
             pip_args = []
-        if package is None:
-            # If no package name is supplied, install only main package
-            #   first in order to see what its name is
-            package = self.install_package_no_deps(package_or_url, pip_args)
+
+        # check syntax and clean up spec and pip_args
+        (package_or_url, pip_args) = parse_specifier_for_install(
+            package_or_url, pip_args
+        )
 
         try:
             with animate(
@@ -227,7 +227,7 @@ class Venv:
         installed_packages = self.list_installed_packages() - old_package_set
         if len(installed_packages) == 1:
             package = installed_packages.pop()
-            logging.info(f"Determined package name: '{package}'")
+            logging.info(f"Determined package name: {package}")
         else:
             logging.info(f"old_package_set = {old_package_set}")
             logging.info(f"install_packages = {installed_packages}")
@@ -288,7 +288,7 @@ class Venv:
         venv_package_metadata = self.get_venv_metadata_for_package(package)
         package_info = PackageInfo(
             package=package,
-            package_or_url=abs_path_if_local(package_or_url, self, pip_args),
+            package_or_url=parse_specifier_for_metadata(package_or_url),
             pip_args=pip_args,
             include_apps=include_apps,
             include_dependencies=include_dependencies,
@@ -365,61 +365,3 @@ class Venv:
         if not self.verbose:
             cmd.append("-q")
         return run(cmd)
-
-
-def abs_path_if_local(package_or_url: str, venv: Venv, pip_args: List[str]) -> str:
-    """Return the absolute path if package_or_url represents a filepath
-    and not a pypi package
-    """
-    # if valid url leave it untouched
-    if urllib.parse.urlparse(package_or_url).scheme:
-        return package_or_url
-
-    pkg_path = Path(package_or_url)
-    if not pkg_path.exists():
-        # no existing path, must be pypi package or non-existent
-        return package_or_url
-
-    # Editable packages are either local or url, non-url must be local.
-    # https://pip.pypa.io/en/stable/reference/pip_install/#editable-installs
-    if "--editable" in pip_args and pkg_path.exists():
-        return str(pkg_path.resolve())
-
-    if not valid_pypi_name(package_or_url):
-        return str(pkg_path.resolve())
-
-    # If all of the above conditions do not return, we may have used a pypi
-    #   package.
-    # If we find a pypi package with this name installed, assume we just
-    #   installed it.
-    pip_search_args: List[str]
-
-    # If user-defined pypi index url, then use it for search
-    try:
-        arg_i = pip_args.index("--index-url")
-    except ValueError:
-        pip_search_args = []
-    else:
-        pip_search_args = pip_args[arg_i : arg_i + 2]
-
-    pip_search_result_str = venv.pip_search(package_or_url, pip_search_args)
-    pip_search_results = pip_search_result_str.split("\n")
-
-    # Get package_or_url and following related lines from pip search stdout
-    pkg_found = False
-    pip_search_found = []
-    for pip_search_line in pip_search_results:
-        if pkg_found:
-            if re.search(r"^\s", pip_search_line):
-                pip_search_found.append(pip_search_line)
-            else:
-                break
-        elif pip_search_line.startswith(package_or_url):
-            pip_search_found.append(pip_search_line)
-            pkg_found = True
-    pip_found_str = " ".join(pip_search_found)
-
-    if pip_found_str.startswith(package_or_url) and "INSTALLED" in pip_found_str:
-        return package_or_url
-    else:
-        return str(pkg_path.resolve())
